pub struct DetachmentBlocker;Expand description
Use for accessing the thread local that determines whether or not DOM futures being dropped should try to detach their nodes from the parent. Rust’s drop glue drops struct fields in order of declaration, so as the last field, we put a struct that will unset the thread local when dropped.
Implementations
Sourceimpl DetachmentBlocker
impl DetachmentBlocker
Sourcepub fn block_until_drop(&self) -> bool
pub fn block_until_drop(&self) -> bool
Block the detachment, returning true iff it was already blocked.
If the detachment was not previously blocked, then this instance of
DetachmentBlocker will “own” the blocking, and detachment will be
unblocked when this instance is dropped.